# R2MIDI Documentation

This directory contains documentation for the R2MIDI project.

## Available Documentation

- [GitHub Secrets Guide](github_secrets_guide.md) - Explains which GitHub secrets are required for macOS signing and PyPI publishing